@@ -38,7 +38,7 @@
 
 #include "MWAWRSRCParser.hxx"
 
-MWAWRSRCParser::MWAWRSRCParser(MWAWInputStreamPtr input) : m_input(input), m_entryMap(), m_parsed(false), m_asciiFile(), m_asciiName("")
+MWAWRSRCParser::MWAWRSRCParser(MWAWInputStreamPtr input) : m_input(input), m_entryMap(), m_asciiName(""), m_asciiFile(MWAWInputStreamPtr()), m_parsed(false)
 {
 }
 
@@ -135,7 +135,7 @@ bool MWAWRSRCParser::parse()
       }
       m_input->seek(tEntry.begin(), librevenge::RVNG_SEEK_SET);
       tEntry.setBegin(tEntry.begin()+4);
-      const long length = (long)m_input->readULong(4);
+      const long length = long(m_input->readULong(4));
       if (tEntry.begin() + length > data.end()) {
         MWAW_DEBUG_MSG(("MWAWRSRCParser::parse: entry %s[%d] has got invalid length %ld\n", tEntry.type().c_str(), tEntry.id(), length));
         continue;
@@ -187,9 +187,9 @@ bool MWAWRSRCParser::parseMap(MWAWEntry const &entry, long dataBegin)
   libmwaw::DebugStream f, f2;
   m_input->seek(entry.begin()+24, librevenge::RVNG_SEEK_SET);
   f << "Entries(RSRCMap):";
-  long offsetTypes=(long)m_input->readULong(2);
-  long offsetNameLists=(long)m_input->readULong(2);
-  int numTypes = (int)m_input->readULong(2);
+  long offsetTypes=long(m_input->readULong(2));
+  long offsetNameLists=long(m_input->readULong(2));
+  int numTypes = static_cast<int>(m_input->readULong(2));
   if (offsetTypes+2 > entry.length() || offsetNameLists > entry.length()) {
     MWAW_DEBUG_MSG(("MWAWRSRCParser::parseMap: the offsets seems bad\n"));
     return false;
@@ -218,11 +218,11 @@ bool MWAWRSRCParser::parseMap(MWAWEntry const &entry, long dataBegin)
     f << "RSRCMap[Type" << i << "]:";
     std::string type("");
     for (int c = 0; c < 4; c++)
-      type+=(char)m_input->readULong(1);
+      type+=char(m_input->readULong(1));
     MWAWEntry tEntry;
     tEntry.setType(type);
-    tEntry.setId((int) m_input->readULong(2)+1); // the number of entry
-    tEntry.setBegin(entry.begin()+offsetTypes+(long) m_input->readULong(2));
+    tEntry.setId(static_cast<int>(m_input->readULong(2))+1); // the number of entry
+    tEntry.setBegin(entry.begin()+offsetTypes+long(m_input->readULong(2)));
     typesList.push_back(tEntry);
     f << tEntry << ":" << std::hex << tEntry.begin() << std::dec << ",";
     ascii().addPos(pos);
@@ -243,17 +243,17 @@ bool MWAWRSRCParser::parseMap(MWAWEntry const &entry, long dataBegin)
       f.str("");
       f << "RSRCMap[Rsrc" << n << "]:";
       MWAWEntry rsrc(tEntry);
-      rsrc.setId((int)m_input->readLong(2));
-      long offset = (long) m_input->readULong(2);
+      rsrc.setId(static_cast<int>(m_input->readLong(2)));
+      long offset = long(m_input->readULong(2));
       if (offset != 0xFFFF) {
         std::string name("");
         if (offset+offsetNameLists+1 <= entry.length()) {
           long actPos = m_input->tell();
           m_input->seek(entry.begin()+offset+offsetNameLists, librevenge::RVNG_SEEK_SET);
-          int nSz = (int) m_input->readULong(1);
+          int nSz = static_cast<int>(m_input->readULong(1));
           if (offset+offsetNameLists+1+nSz <= entry.length()) {
             for (int j = 0; j < nSz; j++)
-              name+=(char)  m_input->readULong(1);
+              name+=char(m_input->readULong(1));
             f2.str("");
             f2 << "nameList:" << name;
             ascii().addPos(entry.begin()+offset+offsetNameLists);
@@ -307,7 +307,7 @@ bool MWAWRSRCParser::parseSTR(MWAWEntry const &entry, std::string &str)
   entry.setParsed(true);
   libmwaw::DebugStream f;
   m_input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-  long sz = (long) m_input->readULong(1);
+  long sz = long(m_input->readULong(1));
   if (sz+1 > entry.length()) {
     MWAW_DEBUG_MSG(("MWAWRSRCParser::parseSTR: string length is too small\n"));
     return false;
@@ -317,7 +317,7 @@ bool MWAWRSRCParser::parseSTR(MWAWEntry const &entry, std::string &str)
       MWAW_DEBUG_MSG(("MWAWRSRCParser::parseSTR: file is too short\n"));
       return false;
     }
-    str += (char) m_input->readULong(1);
+    str += char(m_input->readULong(1));
   }
   f << "Entries(RSRCSTR)[" << entry.type() << ":" << entry.id() << "]:" << str;
   if (sz+1 != entry.length()) {
@@ -345,7 +345,7 @@ bool MWAWRSRCParser::parseSTRList(MWAWEntry const &entry, std::vector<std::strin
 
   libmwaw::DebugStream f;
   f << "Entries(RSRCListStr)[" << entry.type() << ":" << entry.id() << "]:";
-  int N=(int) m_input->readULong(2);
+  int N=static_cast<int>(m_input->readULong(2));
   ascii().addPos(pos-4);
   ascii().addNote(f.str().c_str());
 
@@ -361,7 +361,7 @@ bool MWAWRSRCParser::parseSTRList(MWAWEntry const &entry, std::vector<std::strin
       MWAW_DEBUG_MSG(("MWAWRSRCParser::parseSTRList: can not read string %d\n", i));
       return false;
     }
-    int sz = (int)m_input->readULong(1);
+    int sz = static_cast<int>(m_input->readULong(1));
     if (pos+1+sz > endPos) {
       f.str("");
       f << "###";
@@ -374,7 +374,7 @@ bool MWAWRSRCParser::parseSTRList(MWAWEntry const &entry, std::vector<std::strin
 
     std::string str("");
     for (int c=0; c < sz; c++)
-      str += (char) m_input->readULong(1);
+      str += char(m_input->readULong(1));
     list.push_back(str);
     f << str << ",";
 
@@ -398,10 +398,10 @@ bool MWAWRSRCParser::parseClut(MWAWEntry const &entry, std::vector<MWAWColor> &l
 
   libmwaw::DebugStream f;
   f << "Entries(RSRCClut)[" << entry.type() << ":" << entry.id() << "]:";
-  int flags = (int) m_input->readULong(2);
+  int flags = static_cast<int>(m_input->readULong(2));
   if (flags==0x8000) f << "indexed,";
   else if (flags) f << "#flags=" << std::hex << flags << ",";
-  int N= (int) m_input->readULong(2);
+  int N= static_cast<int>(m_input->readULong(2));
   if (entry.length()==8+8*(N+1)) // N can be num or maxId
     N++;
   f << "N=" << N << ",";
@@ -419,7 +419,7 @@ bool MWAWRSRCParser::parseClut(MWAWEntry const &entry, std::vector<MWAWColor> &l
     pos = m_input->tell();
     f.str("");
     f << "RSRCClut-" << i << ":";
-    int index = (int) m_input->readULong(2);
+    int index = static_cast<int>(m_input->readULong(2));
     if (index != i) {
       static bool first=true;
       if (first) {
@@ -430,7 +430,7 @@ bool MWAWRSRCParser::parseClut(MWAWEntry const &entry, std::vector<MWAWColor> &l
     }
     unsigned char col[3];
     for (int j = 0; j < 3; j++)
-      col[j] = (unsigned char)(m_input->readULong(2)>>8);
+      col[j] = static_cast<unsigned char>(m_input->readULong(2)>>8);
     MWAWColor color(col[0],col[1],col[2]);
     list.push_back(color);
     f << color << ",";
@@ -472,15 +472,15 @@ bool MWAWRSRCParser::parseVers(MWAWEntry const &entry, Version &vers)
   entry.setParsed(true);
   libmwaw::DebugStream f;
   m_input->seek(entry.begin(), librevenge::RVNG_SEEK_SET);
-  vers.m_majorVersion = (int) m_input->readULong(1);
-  vers.m_minorVersion = (int) m_input->readULong(1);
-  long val = (long) m_input->readULong(1);
+  vers.m_majorVersion = static_cast<int>(m_input->readULong(1));
+  vers.m_minorVersion = static_cast<int>(m_input->readULong(1));
+  long val = long(m_input->readULong(1));
   if (val) f << "devStage=" << val << ",";
-  val = (long) m_input->readULong(1);
+  val = long(m_input->readULong(1));
   if (val) f << "preReleaseLevel=" << std::hex << val << std::dec << ",";
-  vers.m_countryCode = (int) m_input->readULong(2);
+  vers.m_countryCode = static_cast<int>(m_input->readULong(2));
   for (int i = 0; i < 2; i++) {
-    int sz = (int) m_input->readULong(1);
+    int sz = static_cast<int>(m_input->readULong(1));
     long pos = m_input->tell();
     if (pos+sz > entry.end()) {
       MWAW_DEBUG_MSG(("MWAWRSRCParser::parseVers: can not read strings %d\n",i));
@@ -488,7 +488,7 @@ bool MWAWRSRCParser::parseVers(MWAWEntry const &entry, Version &vers)
     }
     std::string str("");
     for (int c = 0; c < sz; c++)
-      str+=(char) m_input->readULong(1);
+      str+=char(m_input->readULong(1));
     if (i==0)
       vers.m_versionString = str;
     else
