@@ -61,7 +61,7 @@ namespace MacWrtProParserInternal
 ////////////////////////////////////////
 //! Internal: a struct used to store a zone
 struct Zone {
-  Zone() : m_type(-1), m_blockId(0), m_data(), m_input(), m_asciiFile(), m_parsed(false)
+  Zone() : m_type(-1), m_blockId(0), m_data(), m_input(), m_asciiFile(MWAWInputStreamPtr()), m_parsed(false)
   {
   }
   ~Zone()
@@ -436,12 +436,12 @@ bool MacWrtProParser::getZoneData(librevenge::RVNGBinaryData &data, int blockId)
   while (!input->isEnd()) {
     bool ok = true;
     for (long i=first; i<= last; i++) {
-      if (m_state->m_blocksMap.find((int)i) != m_state->m_blocksMap.end()) {
+      if (m_state->m_blocksMap.find(static_cast<int>(i)) != m_state->m_blocksMap.end()) {
         MWAW_DEBUG_MSG(("MacWrtProParser::getZoneData: block %ld already seems\n", i));
         ok = false;
         break;
       }
-      m_state->m_blocksMap[(int)i] = (long)data.size()+(i-first)*0x100;
+      m_state->m_blocksMap[static_cast<int>(i)] = long(data.size())+(i-first)*0x100;
     }
     if (!ok) break;
     long endPos = (last+1)*0x100 - linkSz;
@@ -480,7 +480,7 @@ bool MacWrtProParser::getZoneData(librevenge::RVNGBinaryData &data, int blockId)
       }
     }
     if (val < 0) {
-      long num = (long) input->readULong(linkSz);
+      long num = long(input->readULong(linkSz));
       last = first+(num-1);
     }
     if (last-first > 2) {
@@ -513,13 +513,13 @@ bool MacWrtProParser::getFreeZoneList(int blockId, std::vector<int> &blockLists)
   while (1) {
     bool ok = true;
     for (long i=first; i<= last; i++) {
-      if (m_state->m_blocksMap.find((int)i) != m_state->m_blocksMap.end()) {
+      if (m_state->m_blocksMap.find(static_cast<int>(i)) != m_state->m_blocksMap.end()) {
         MWAW_DEBUG_MSG(("MacWrtProParser::getFreeZoneList: block %ld already seems\n", i));
         ok = false;
         break;
       }
-      blockLists.push_back((int)i);
-      m_state->m_blocksMap[(int)i] = 0;
+      blockLists.push_back(static_cast<int>(i));
+      m_state->m_blocksMap[static_cast<int>(i)] = 0;
     }
     if (!ok) break;
     long endPos = (last+1)*0x100 - 4;
@@ -544,7 +544,7 @@ bool MacWrtProParser::getFreeZoneList(int blockId, std::vector<int> &blockLists)
         }
       }
 
-      long num = (long) input->readULong(4);
+      long num = long(input->readULong(4));
       last = first+(num-1);
     }
   }
@@ -671,8 +671,8 @@ bool MacWrtProParser::checkHeader(MWAWHeader *header, bool strict)
   }
   input->seek(0,librevenge::RVNG_SEEK_SET);
 
-  int vers = (int) input->readULong(2);
-  int val = (int) input->readULong(2);
+  int vers = static_cast<int>(input->readULong(2));
+  int val = static_cast<int>(input->readULong(2));
 
   f << "FileHeader:";
   switch (vers) {
@@ -709,10 +709,10 @@ bool MacWrtProParser::checkHeader(MWAWHeader *header, bool strict)
     else if (!readPrintInfo()) { // last chance, check DocHeader
       input->seek(4+0x78, librevenge::RVNG_SEEK_SET);
       if (input->readULong(2)) return false;
-      val=(int) input->readULong(2);
+      val=static_cast<int>(input->readULong(2));
       if ((val&0x0280)!=0x0280) return false;
       for (int i=0; i<4; ++i) {
-        val=(int) input->readLong(1);
+        val=static_cast<int>(input->readLong(1));
         if (val<-1 || val>1) return false;
       }
     }
@@ -835,15 +835,15 @@ bool MacWrtProParser::readDocHeader()
   else {
     val = input->readLong(1); // always 0 ?
     if (val) f << "unkn=" << val << ",";
-    int N=(int) input->readLong(2); // find 2, a, 9e, 1a
+    int N=static_cast<int>(input->readLong(2)); // find 2, a, 9e, 1a
     f << "N?=" << N << ",";
-    N = (int) input->readLong(1); // almost always 0, find one time 6 ?
+    N = static_cast<int>(input->readLong(1)); // almost always 0, find one time 6 ?
     if (N) f << "N1?=" << N << ",";
-    val = (int) input->readLong(2); // almost always 0x622, find also 0 and 12
+    val = static_cast<int>(input->readLong(2)); // almost always 0x622, find also 0 and 12
     f << "f0=" << std::hex << val << std::dec << ",";
-    val = (int) input->readLong(1); // always 0 ?
+    val = static_cast<int>(input->readLong(1)); // always 0 ?
     if (val) f << "unkn1=" << val << ",";
-    N = (int) input->readLong(2);
+    N = static_cast<int>(input->readLong(2));
     f << "N2?=" << N << ",";
     val = input->readLong(1); // almost always 1 ( find one time 2)
     f << "f1=" << val << ",";
@@ -860,7 +860,7 @@ bool MacWrtProParser::readDocHeader()
     }
     val = input->readLong(2); // always 480 ?
     if (val != 0x480) f << "f10=" << val << ",";
-    val = (long) input->readULong(1); // always 0 ?
+    val = long(input->readULong(1)); // always 0 ?
     if (val) f << "f11=" << val << ",";
   }
   float dim[6];
@@ -873,13 +873,13 @@ bool MacWrtProParser::readDocHeader()
   if (ok) ok = dim[0] > dim[2]+dim[3] && dim[1] > dim[4]+dim[5];
 
   if (ok) {
-    getPageSpan().setMarginTop(dim[2]/72.0);
-    getPageSpan().setMarginLeft(dim[4]/72.0);
+    getPageSpan().setMarginTop(double(dim[2])/72.0);
+    getPageSpan().setMarginLeft(double(dim[4])/72.0);
     /* decrease a little the right/bottom margin to allow fonts discrepancy*/
-    getPageSpan().setMarginBottom((dim[3]<36.0) ? 0.0 : dim[3]/72.0-0.5);
-    getPageSpan().setMarginRight((dim[5]<18.0) ? 0.0 : dim[5]/72.0-0.25);
-    getPageSpan().setFormLength(dim[0]/72.);
-    getPageSpan().setFormWidth(dim[1]/72.);
+    getPageSpan().setMarginBottom((dim[3]<36) ? 0.0 : double(dim[3])/72.0-0.5);
+    getPageSpan().setMarginRight((dim[5]<18) ? 0.0 : double(dim[5])/72.0-0.25);
+    getPageSpan().setFormLength(double(dim[0])/72.);
+    getPageSpan().setFormWidth(double(dim[1])/72.);
   }
   else {
     MWAW_DEBUG_MSG(("MacWrtProParser::readDocHeader: find odd page dimensions, ignored\n"));
@@ -890,7 +890,7 @@ bool MacWrtProParser::readDocHeader()
   for (int i = 2; i < 6; i++) f << dim[i] << ",";
   f << "],";
   if (version()==0) {
-    m_state->m_col = (int) input->readLong(2);
+    m_state->m_col = static_cast<int>(input->readLong(2));
     if (m_state->m_col != 1) f << "col=" << m_state->m_col << ",";
   }
 
@@ -909,14 +909,14 @@ bool MacWrtProParser::readDocHeader()
     input->seek(pos+120, librevenge::RVNG_SEEK_SET);
     pos = input->tell();
     for (int i = 0; i < 3; i++) { // f0=f1, f2=0
-      val = (long) input->readULong(4);
+      val = long(input->readULong(4));
       if (val) f << "f" << i << "=" << std::hex << val << std::dec << ",";
     }
   }
   else {
     input->seek(pos+97, librevenge::RVNG_SEEK_SET);
     pos = input->tell();
-    val = (long) input->readULong(2);
+    val = long(input->readULong(2));
     if (val != 0x4d50) // MP
       f << "#keyWord=" << std::hex << val <<std::dec;
     //always 4, 4, 6 ?
@@ -942,7 +942,7 @@ bool MacWrtProParser::readDocHeader()
   }
   // always 0 ?
   for (int i = 2; i < 42; i++) {
-    val = (long) input->readULong(2);
+    val = long(input->readULong(2));
     if (val) f << "g"  << i << "=" << std::hex << val << std::dec << ",";
   }
   ascii().addPos(pos);
@@ -1026,7 +1026,7 @@ bool MacWrtProParser::parseTextZone(shared_ptr<MacWrtProParserInternal::Zone> zo
   long pos = 0;
   input->seek(pos, librevenge::RVNG_SEEK_SET);
   f << "Entries(TextZone):";
-  text->m_textLength = (int)input->readLong(4);
+  text->m_textLength = static_cast<int>(input->readLong(4));
   f << "textLength=" << text->m_textLength << ",";
 
   asciiFile.addPos(pos);
@@ -1069,8 +1069,8 @@ bool MacWrtProParser::readTextEntries(shared_ptr<MacWrtProParserInternal::Zone>
   libmwaw::DebugStream f;
   long pos = input->tell();
 
-  int val = (int) input->readULong(2);
-  int sz = (int) input->readULong(2);
+  int val = static_cast<int>(input->readULong(2));
+  int sz = static_cast<int>(input->readULong(2));
   if ((sz%expectedSize) != 0) {
     MWAW_DEBUG_MSG(("MacWrtProParser::readTextEntries: find an odd size\n"));
     return false;
@@ -1090,12 +1090,12 @@ bool MacWrtProParser::readTextEntries(shared_ptr<MacWrtProParserInternal::Zone>
     f << "TextZone-" << i<<":entry,";
     int unkn = 0;
     if (vers >= 1) {
-      unkn = (int) input->readLong(2);
+      unkn = static_cast<int>(input->readLong(2));
       if (unkn) f << "unkn=" << unkn << ",";
     }
-    int bl = (int) input->readLong(2);
+    int bl = static_cast<int>(input->readLong(2));
     f << "block=" << std::hex << bl << std::dec << ",";
-    int nChar = (int) input->readULong(2);
+    int nChar = static_cast<int>(input->readULong(2));
     f << "blockSz=" << nChar;
 
     if (nChar > remainLength || nChar > 256) {
@@ -1143,8 +1143,8 @@ bool MacWrtProParser::readTextIds(shared_ptr<MacWrtProParserInternal::Zone> zone
   libmwaw::DebugStream f;
   long pos = input->tell();
 
-  int val = (int) input->readULong(2);
-  int sz = (int) input->readULong(2);
+  int val = static_cast<int>(input->readULong(2));
+  int sz = static_cast<int>(input->readULong(2));
   if (sz == 0) {
     asciiFile.addPos(pos);
     asciiFile.addNote("_");
@@ -1168,9 +1168,9 @@ bool MacWrtProParser::readTextIds(shared_ptr<MacWrtProParserInternal::Zone> zone
     MacWrtProParserInternal::TextZoneData data;
     data.m_type = type;
     pos = input->tell();
-    data.m_id = (int) input->readLong(2);
-    long nChar = (long) input->readULong(4);
-    data.m_length = (int) nChar;
+    data.m_id = static_cast<int>(input->readLong(2));
+    long nChar = long(input->readULong(4));
+    data.m_length = static_cast<int>(nChar);
     f.str("");
     f << "TextZone-" << i<< ":" << data;
 
@@ -1209,14 +1209,14 @@ bool MacWrtProParser::readTextTokens(shared_ptr<MacWrtProParserInternal::Zone> z
   libmwaw::DebugStream f;
   long pos = input->tell();
 
-  int val = (int) input->readULong(2);
+  int val = static_cast<int>(input->readULong(2));
   if (val && vers == 0) {
     input->seek(pos, librevenge::RVNG_SEEK_SET);
     asciiFile.addPos(pos);
     asciiFile.addNote("_");
     return true;
   }
-  long sz = (int) input->readULong(2);
+  long sz = static_cast<int>(input->readULong(2));
   if (sz == 0) {
     asciiFile.addPos(pos);
     asciiFile.addNote("_");
@@ -1243,7 +1243,7 @@ bool MacWrtProParser::readTextTokens(shared_ptr<MacWrtProParserInternal::Zone> z
     pos = input->tell();
 
     MacWrtProParserInternal::Token data;
-    data.m_type = (int) input->readULong(1);
+    data.m_type = static_cast<int>(input->readULong(1));
     if (vers==0) { // check me
       switch (data.m_type) {
       case 2:  // page number
@@ -1271,14 +1271,14 @@ bool MacWrtProParser::readTextTokens(shared_ptr<MacWrtProParserInternal::Zone> z
         break;
       }
     }
-    data.m_flags[0] = (int) input->readULong(1);
-    long nChar = (long) input->readULong(vers == 0 ? 2 : 4);
-    data.m_length = (int) nChar;
-    for (int j = 1; j < 3; j++) data.m_flags[j] = (int) input->readULong(1);
+    data.m_flags[0] = static_cast<int>(input->readULong(1));
+    long nChar = long(input->readULong(vers == 0 ? 2 : 4));
+    data.m_length = static_cast<int>(nChar);
+    for (int j = 1; j < 3; j++) data.m_flags[j] = static_cast<int>(input->readULong(1));
     if (vers == 0)
-      data.m_flags[3] = (int) input->readULong(2);
+      data.m_flags[3] = static_cast<int>(input->readULong(2));
     else
-      data.m_blockId = (int) input->readULong(2);
+      data.m_blockId = static_cast<int>(input->readULong(2));
     f << "TextZone-" << i<< ":token," << data;
     if (nChar > remainLength) {
       MWAW_DEBUG_MSG(("MacWrtProParser::readTextTokens: bad size for block %d\n", i));
@@ -1288,7 +1288,7 @@ bool MacWrtProParser::readTextTokens(shared_ptr<MacWrtProParserInternal::Zone> z
     remainLength -= nChar;
     asciiFile.addPos(pos);
     asciiFile.addNote(f.str().c_str());
-    if (data.m_type == 4) pictPos.push_back((int)res.size());
+    if (data.m_type == 4) pictPos.push_back(static_cast<int>(res.size()));
     res.push_back(data);
 
     if (vers == 1 && data.m_blockId && (data.m_type == 2 || data.m_type == 4))
@@ -1299,26 +1299,26 @@ bool MacWrtProParser::readTextTokens(shared_ptr<MacWrtProParserInternal::Zone> z
     size_t numPict = pictPos.size();
     // checkme always inverted ?
     for (size_t i = numPict; i > 0; i--) {
-      MacWrtProParserInternal::Token &token = res[(size_t) pictPos[i-1]];
+      MacWrtProParserInternal::Token &token = res[size_t(pictPos[i-1])];
       pos = input->tell();
       f.str("");
       f << "TextZone-pict" << i-1<< ":";
-      val = (int) input->readLong(2);
+      val = static_cast<int>(input->readLong(2));
       if (val) f << "unkn=" << val << ",";
-      int blockId = (int) input->readULong(2);
+      int blockId = static_cast<int>(input->readULong(2));
       if (blockId) {
         token.m_blockId = blockId;
         f << "block=" << blockId << ",";
         parseDataZone(blockId,1);
       }
-      sz = (long) input->readULong(4);
+      sz = long(input->readULong(4));
       f << "sz=" << std::hex << sz << std::dec << ",";
       int dim[4];
-      for (int j = 0; j < 4; j++) dim[j] = (int) input->readLong(2);
+      for (int j = 0; j < 4; j++) dim[j] = static_cast<int>(input->readLong(2));
       token.m_box = MWAWBox2f(MWAWVec2f(float(dim[1]),float(dim[0])), MWAWVec2f(float(dim[3]),float(dim[2])));
       f << "dim=[" << dim[1] << "x" << dim[0] << "-"
         << dim[3] << "x" << dim[2] << ",";
-      for (int j = 0; j < 4; j++) dim[j] = (int) input->readLong(2);
+      for (int j = 0; j < 4; j++) dim[j] = static_cast<int>(input->readLong(2));
       f << "dim2=[" << dim[1] << "x" << dim[0] << "-"
         << dim[3] << "x" << dim[2] << ",";
       // followed by junk ?
@@ -1445,19 +1445,19 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
   set(compareFunction);
   long cPos = 0;
   for (size_t i = 0; i < zone->m_entries.size(); i++) {
-    set.insert(MacWrtProParserInternal::DataPosition(3, (int) i, cPos));
+    set.insert(MacWrtProParserInternal::DataPosition(3, static_cast<int>(i), cPos));
     cPos += zone->m_entries[i].length();
   }
   set.insert(MacWrtProParserInternal::DataPosition(4, 0, cPos));
   cPos = 0;
   for (size_t i = 0; i < zone->m_tokens.size(); i++) {
     cPos += zone->m_tokens[i].m_length;
-    set.insert(MacWrtProParserInternal::DataPosition(2, (int) i, cPos));
+    set.insert(MacWrtProParserInternal::DataPosition(2, static_cast<int>(i), cPos));
   }
   for (int id = 0; id < 2; id++) {
     cPos = 0;
     for (size_t i = 0; i < zone->m_ids[id].size(); i++) {
-      set.insert(MacWrtProParserInternal::DataPosition(1-id, (int) i, cPos));
+      set.insert(MacWrtProParserInternal::DataPosition(1-id, static_cast<int>(i), cPos));
       cPos += zone->m_ids[id][i].m_length;
     }
   }
@@ -1467,7 +1467,7 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
       MWAW_DEBUG_MSG(("MacWrtProParser::sendText: page breaks seems bad\n"));
       break;
     }
-    set.insert(MacWrtProParserInternal::DataPosition(-1, (int) i, pageBreaks[i]));
+    set.insert(MacWrtProParserInternal::DataPosition(-1, static_cast<int>(i), pageBreaks[i]));
   }
 
   MWAWInputStreamPtr input = getInput();
@@ -1491,7 +1491,7 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
       if (pos > 0) {
         std::string text("");
         for (long i = cPos; i < data.m_pos; i++) {
-          char ch = (char) input->readULong(1);
+          char ch = char(input->readULong(1));
           if (!ch)
             text+= "#";
           else {
@@ -1523,7 +1523,7 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
       if (pos > 0 && (pos&0xFF))
         ascii().addDelimiter(pos,'|');
       if (data.m_type == 3) {
-        pos = zone->m_entries[(size_t)data.m_id].begin();
+        pos = zone->m_entries[size_t(data.m_id)].begin();
         if (pos > 0)
           input->seek(pos, librevenge::RVNG_SEEK_SET);
       }
@@ -1531,16 +1531,16 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
     case 2: {
       // save the position because we read some extra data ( footnote, table, textbox)
       long actPos = input->tell();
-      switch (zone->m_tokens[(size_t)data.m_id].m_type) {
+      switch (zone->m_tokens[size_t(data.m_id)].m_type) {
       case 1:
         if (getTextListener()) getTextListener()->insertField(MWAWField(MWAWField::PageNumber));
         break;
       case 2:
-        if (vers == 1 && listenerState.isSent(zone->m_tokens[(size_t)data.m_id].m_blockId)) {
+        if (vers == 1 && listenerState.isSent(zone->m_tokens[size_t(data.m_id)].m_blockId)) {
           MWAW_DEBUG_MSG(("MacWrtProParser::sendText: footnote is already sent...\n"));
         }
         else {
-          int id = zone->m_tokens[(size_t)data.m_id].m_blockId;
+          int id = zone->m_tokens[size_t(data.m_id)].m_blockId;
           if (vers == 0) id = -id;
           MWAWSubDocumentPtr subdoc(new MacWrtProParserInternal::SubDocument(*this, getInput(), id));
           getTextListener()->insertNote(MWAWNote(MWAWNote::FootNote), subdoc);
@@ -1550,12 +1550,12 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
         break; // footnote content, ok
       case 4:
         if (vers==0) {
-          MWAWPosition pictPos(MWAWVec2i(0,0), zone->m_tokens[(size_t)data.m_id].m_box.size(), librevenge::RVNG_POINT);
+          MWAWPosition pictPos(MWAWVec2i(0,0), zone->m_tokens[size_t(data.m_id)].m_box.size(), librevenge::RVNG_POINT);
           pictPos.setRelativePosition(MWAWPosition::Char, MWAWPosition::XLeft, MWAWPosition::YBottom);
-          sendPictureZone(zone->m_tokens[(size_t)data.m_id].m_blockId, pictPos);
+          sendPictureZone(zone->m_tokens[size_t(data.m_id)].m_blockId, pictPos);
         }
         else {
-          listenerState.send(zone->m_tokens[(size_t)data.m_id].m_blockId);
+          listenerState.send(zone->m_tokens[size_t(data.m_id)].m_blockId);
           listenerState.resendAll();
         }
         break;
@@ -1571,38 +1571,38 @@ bool MacWrtProParser::sendText(shared_ptr<MacWrtProParserInternal::TextZone> zon
         if (getTextListener()) getTextListener()->insertField(MWAWField(MWAWField::Title));
         break;
       case 9:
-        if (getTextListener()) getTextListener()->insertUnicodeString("#REVISION#");
+        if (getTextListener()) getTextListener()->insertUnicodeString(librevenge::RVNGString("#REVISION#"));
         break;
       case 10:
         if (getTextListener()) {
           int numSection = listenerState.numSection()+1;
           std::stringstream s;
           s << numSection;
-          getTextListener()->insertUnicodeString(s.str().c_str());
+          getTextListener()->insertUnicodeString(librevenge::RVNGString(s.str().c_str()));
         }
         break;
       default:
         break;
       }
-      f << "token[" << zone->m_tokens[(size_t)data.m_id] << "],";
+      f << "token[" << zone->m_tokens[size_t(data.m_id)] << "],";
       input->seek(actPos, librevenge::RVNG_SEEK_SET);
       break;
     }
     case 1:
       if (m_structures) {
-        listenerState.sendFont(zone->m_ids[0][(size_t)data.m_id].m_id);
-        f << "[" << listenerState.getFontDebugString(zone->m_ids[0][(size_t)data.m_id].m_id) << "],";
+        listenerState.sendFont(zone->m_ids[0][size_t(data.m_id)].m_id);
+        f << "[" << listenerState.getFontDebugString(zone->m_ids[0][size_t(data.m_id)].m_id) << "],";
       }
       else
-        f << "[" << zone->m_ids[0][(size_t)data.m_id] << "],";
+        f << "[" << zone->m_ids[0][size_t(data.m_id)] << "],";
       break;
     case 0:
       if (m_structures) {
-        listenerState.sendParagraph(zone->m_ids[1][(size_t)data.m_id].m_id);
-        f << "[" << listenerState.getParagraphDebugString(zone->m_ids[1][(size_t)data.m_id].m_id) << "],";
+        listenerState.sendParagraph(zone->m_ids[1][size_t(data.m_id)].m_id);
+        f << "[" << listenerState.getParagraphDebugString(zone->m_ids[1][size_t(data.m_id)].m_id) << "],";
       }
       else
-        f << "[" << zone->m_ids[1][(size_t)data.m_id] << "],";
+        f << "[" << zone->m_ids[1][size_t(data.m_id)] << "],";
       break;
     default: {
       static bool firstError = true;
@@ -1660,14 +1660,14 @@ bool MacWrtProParser::sendPicture(shared_ptr<MacWrtProParserInternal::Zone> zone
   asciiFile.addNote(f.str().c_str());
 
   input->seek(0, librevenge::RVNG_SEEK_SET);
-  long pictSize = (long) input->readULong(4);
+  long pictSize = long(input->readULong(4));
   if (pictSize < 10 || pictSize > long(zone->m_data.size())) {
     MWAW_DEBUG_MSG(("MacWrtProParser::sendPicture: oops a pb with pictSize\n"));
     asciiFile.addPos(4);
     asciiFile.addNote("#PICT");
     return false;
   }
-  shared_ptr<MWAWPict> pict(MWAWPictData::get(input, (int)pictSize));
+  shared_ptr<MWAWPict> pict(MWAWPictData::get(input, static_cast<int>(pictSize)));
   if (!pict) {
     // sometimes this just fails because the pictSize is not correct
     input->seek(14, librevenge::RVNG_SEEK_SET);
@@ -1691,7 +1691,7 @@ bool MacWrtProParser::sendPicture(shared_ptr<MacWrtProParserInternal::Zone> zone
       }
 
       pictInput->seek(4, librevenge::RVNG_SEEK_SET);
-      pict.reset(MWAWPictData::get(pictInput, (int)pictSize));
+      pict.reset(MWAWPictData::get(pictInput, static_cast<int>(pictSize)));
     }
   }
 
@@ -1747,8 +1747,7 @@ void MacWrtProParser::saveOriginal(MWAWInputStreamPtr input)
   libmwaw::DebugStream f;
 
   int ptSz = version()==0 ? 2 : 4;
-  libmwaw::DebugFile orig;
-  orig.setStream(input);
+  libmwaw::DebugFile orig(input);
   orig.open("orig");
   int bl = 0;
   while (1) {
@@ -1808,7 +1807,7 @@ void MacWrtProParser::checkUnparsed()
     std::string text("");
     bool findZero = false;
     for (int c = 0; c < 256; c++) {
-      char ch = (char) input->readULong(1);
+      char ch = char(input->readULong(1));
       if (!ch) {
         if (findZero) {
           input->seek(-1, librevenge::RVNG_SEEK_CUR);
